@@ -265,7 +265,7 @@ tzfree(timezone_t env)
 }
 #endif /* ! USE_LOCALTIME_RZ */
 
-/* A UTC time zone, and its initializer.  */
+/* A UT time zone, and its initializer.  */
 static timezone_t gmtz;
 static void
 gmtzinit(void)
@@ -280,7 +280,7 @@ gmtzinit(void)
   }
 }
 
-/* Convert *TP to UTC, storing the broken-down time into *TMP.
+/* Convert *TP to UT, storing the broken-down time into *TMP.
    Return TMP if successful, NULL otherwise.  This is like gmtime_r(TP, TMP),
    except typically faster if USE_LOCALTIME_RZ.  */
 static struct tm *
@@ -552,6 +552,7 @@ main(int argc, char *argv[])
 		}
 		if (t < cutlotime)
 			t = cutlotime;
+		INITIALIZE (ab);
 		tm_ok = my_localtime_rz(tz, &t, &tm) != NULL;
 		if (tm_ok) {
 		  ab = saveabbr(&abbrev, &abbrevsize, &tm);
@@ -567,11 +568,10 @@ main(int argc, char *argv[])
 				 : cuthitime);
 		  struct tm *newtmp = localtime_rz(tz, &newt, &newtm);
 		  bool newtm_ok = newtmp != NULL;
-		  if (! (tm_ok & newtm_ok
-			 ? (delta(&newtm, &tm) == newt - t
-			    && newtm.tm_isdst == tm.tm_isdst
-			    && strcmp(abbr(&newtm), ab) == 0)
-			 : tm_ok == newtm_ok)) {
+		  if (tm_ok != newtm_ok
+		      || (tm_ok && (delta(&newtm, &tm) != newt - t
+				    || newtm.tm_isdst != tm.tm_isdst
+				    || strcmp(abbr(&newtm), ab) != 0))) {
 		    newt = hunt(tz, argv[i], t, newt);
 		    newtmp = localtime_rz(tz, &newt, &newtm);
 		    newtm_ok = newtmp != NULL;
@@ -730,8 +730,8 @@ adjusted_yday(struct tm const *a, struct tm const *b)
 }
 #endif
 
-/* If A is the broken-down local time and B the broken-down UTC for
-   the same instant, return A's UTC offset in seconds, where positive
+/* If A is the broken-down local time and B the broken-down UT for
+   the same instant, return A's UT offset in seconds, where positive
    offsets are east of Greenwich.  On failure, return LONG_MIN.
 
    If T is nonnull, *T is the timestamp that corresponds to A; call
@@ -795,12 +795,14 @@ show(timezone_t tz, char *zone, time_t t, bool v)
 		abbrok(abbr(tmp), zone);
 }
 
-#if !HAVE_SNPRINTF
+#if HAVE_SNPRINTF
+# define my_snprintf snprintf
+#else
 # include <stdarg.h>
 
 /* A substitute for snprintf that is good enough for zdump.  */
-static int
-snprintf(char *s, size_t size, char const *format, ...)
+static int ATTRIBUTE_FORMAT((printf, 3, 4))
+my_snprintf(char *s, size_t size, char const *format, ...)
 {
   int n;
   va_list args;
@@ -839,16 +841,16 @@ format_local_time(char *buf, size_t size, struct tm const *tm)
 {
   int ss = tm->tm_sec, mm = tm->tm_min, hh = tm->tm_hour;
   return (ss
-	  ? snprintf(buf, size, "%02d:%02d:%02d", hh, mm, ss)
+	  ? my_snprintf(buf, size, "%02d:%02d:%02d", hh, mm, ss)
 	  : mm
-	  ? snprintf(buf, size, "%02d:%02d", hh, mm)
-	  : snprintf(buf, size, "%02d", hh));
+	  ? my_snprintf(buf, size, "%02d:%02d", hh, mm)
+	  : my_snprintf(buf, size, "%02d", hh));
 }
 
-/* Store into BUF, of size SIZE, a formatted UTC offset for the
+/* Store into BUF, of size SIZE, a formatted UT offset for the
    localtime *TM corresponding to time T.  Use ISO 8601 format
    +HHMMSS, or -HHMMSS for timestamps west of Greenwich; use the
-   format -00 for unknown UTC offsets.  If the hour needs more than
+   format -00 for unknown UT offsets.  If the hour needs more than
    two digits to represent, extend the length of HH as needed.
    Otherwise, omit SS if SS is zero, and omit MM too if MM is also
    zero.
@@ -877,10 +879,10 @@ format_utc_offset(char *buf, size_t size, struct tm const *tm, time_t t)
   mm = off / 60 % 60;
   hh = off / 60 / 60;
   return (ss || 100 <= hh
-	  ? snprintf(buf, size, "%c%02ld%02d%02d", sign, hh, mm, ss)
+	  ? my_snprintf(buf, size, "%c%02ld%02d%02d", sign, hh, mm, ss)
 	  : mm
-	  ? snprintf(buf, size, "%c%02ld%02d", sign, hh, mm)
-	  : snprintf(buf, size, "%c%02ld", sign, hh));
+	  ? my_snprintf(buf, size, "%c%02ld%02d", sign, hh, mm)
+	  : my_snprintf(buf, size, "%c%02ld", sign, hh));
 }
 
 /* Store into BUF (of size SIZE) a quoted string representation of P.
@@ -923,7 +925,7 @@ format_quoted_string(char *buf, size_t size, char const *p)
 
    %f zone name
    %L local time as per format_local_time
-   %Q like "U\t%Z\tD" where U is the UTC offset as for format_utc_offset
+   %Q like "U\t%Z\tD" where U is the UT offset as for format_utc_offset
       and D is the isdst flag; except omit D if it is zero, omit %Z if
       it equals U, quote and escape %Z if it contains nonalphabetics,
       and omit any trailing tabs.  */
@@ -983,15 +985,16 @@ istrftime(char *buf, size_t size, char const *time_fmt,
 	    for (abp = ab; is_alpha(*abp); abp++)
 	      continue;
 	    len = (!*abp && *ab
-		   ? snprintf(b, s, "%s", ab)
+		   ? my_snprintf(b, s, "%s", ab)
 		   : format_quoted_string(b, s, ab));
 	    if (s <= len)
 	      return false;
 	    b += len, s -= len;
 	  }
-	  formatted_len = (tm->tm_isdst
-			   ? snprintf(b, s, &"\t\t%d"[show_abbr], tm->tm_isdst)
-			   : 0);
+	  formatted_len
+	    = (tm->tm_isdst
+	       ? my_snprintf(b, s, &"\t\t%d"[show_abbr], tm->tm_isdst)
+	       : 0);
 	}
 	break;
       }
